@@ -4,7 +4,7 @@ use std::mem;
 
 use crate::{TYPE_STR_IDX, TYPE_VARINT};
 
-use super::{StrConfig, Value, Buffer, RpResult, ErrorKind};
+use super::{Value, Buffer, RpResult, ErrorKind};
 use super::{TYPE_NIL, TYPE_BOOL, TYPE_U8, TYPE_I8, TYPE_U16, TYPE_I16, TYPE_U32, TYPE_I32, TYPE_U64, TYPE_I64, TYPE_FLOAT, TYPE_DOUBLE, TYPE_STR,
      TYPE_RAW, TYPE_ARR, TYPE_MAP};
 use super::{make_extension_error};
@@ -153,28 +153,28 @@ pub fn decode_str_raw(buffer: &mut Buffer, pattern: u8) -> RpResult<Value> {
     }
 }
 
-pub fn decode_map(buffer: &mut Buffer, config: &StrConfig) -> RpResult<Value> {
+pub fn decode_map(buffer: &mut Buffer) -> RpResult<Value> {
     let mut map = HashMap::<Value, Value>::new();
     let arr_len: u16 = decode_varint(buffer)?.into();
     for _ in 0 .. arr_len {
-        let key = decode_field(buffer, config)?;
-        let sub_value = decode_field(buffer, config)?;
+        let key = decode_field(buffer)?;
+        let sub_value = decode_field(buffer)?;
         map.insert(key, sub_value);
     }
     Ok(Value::from(map))
 }
 
-pub fn decode_arr(buffer: &mut Buffer, config: &StrConfig) -> RpResult<Value> {
+pub fn decode_arr(buffer: &mut Buffer) -> RpResult<Value> {
     let mut arr = Vec::<Value>::new();
     let arr_len: u16 = decode_varint(buffer)?.into();
     for _ in 0 .. arr_len {
-        let sub_value = decode_field(buffer, config)?;
+        let sub_value = decode_field(buffer)?;
         arr.push(sub_value);
     }
     Ok(Value::from(arr))
 }
 
-fn decode_by_pattern(buffer: &mut Buffer, config: &StrConfig, pattern: &u8) -> RpResult<Value> {
+fn decode_by_pattern(buffer: &mut Buffer, pattern: &u8) -> RpResult<Value> {
     match *pattern {
         TYPE_BOOL => {
             decode_bool(buffer, *pattern)
@@ -186,11 +186,11 @@ fn decode_by_pattern(buffer: &mut Buffer, config: &StrConfig, pattern: &u8) -> R
             decode_varint(buffer)
         }
         TYPE_STR | TYPE_RAW => decode_str_raw(buffer, *pattern),
-        TYPE_MAP => decode_map(buffer, &config),
-        TYPE_ARR => decode_arr(buffer, &config),
+        TYPE_MAP => decode_map(buffer),
+        TYPE_ARR => decode_arr(buffer),
         TYPE_STR_IDX => {
             let idx: u16 = decode_varint(buffer)?.into();
-            Ok(Value::from(config.get_str(idx)?))
+            Ok(Value::from(buffer.get_str(idx)?))
         },
         // TYPE_AMAP => decode_array!(decode_field(buffer, config), Value::AMap, Value::Map),
         TYPE_NIL => Ok(Value::Nil),
@@ -199,22 +199,22 @@ fn decode_by_pattern(buffer: &mut Buffer, config: &StrConfig, pattern: &u8) -> R
 }
 
 
-pub fn decode_field(buffer: &mut Buffer, config: &StrConfig) -> RpResult<Value> {
+pub fn decode_field(buffer: &mut Buffer) -> RpResult<Value> {
     let pattern = decode_type(buffer)?.into();
-    decode_by_pattern(buffer, config, &pattern)
+    decode_by_pattern(buffer, &pattern)
 }
 
 pub fn decode_proto(buffer: &mut Buffer) -> RpResult<(String, Vec<Value>)> {
-    let str_len: u16 = decode_number(buffer, TYPE_U16)?.into();
-    let mut config = StrConfig::new();
+    let name = decode_str_raw(buffer, TYPE_STR)?.into();
+    
+    let str_len: u16 = decode_varint(buffer)?.into();
     for _ in 0..str_len {
         let value = decode_str_raw(buffer, TYPE_STR)?.into();
-        config.add_str(value);
+        buffer.add_str(value);
     }
 
-    let name = decode_str_raw(buffer, TYPE_STR)?.into();
     println!("name = {}", name);
-    let sub_value = decode_field(buffer, &config)?;
+    let sub_value = decode_field(buffer)?;
     match sub_value {
         Value::Arr(val) => Ok((name, val)),
         _ => Err(make_extension_error("proto is not array", None))
