@@ -3,13 +3,11 @@ extern crate rustc_serialize;
 
 pub mod macros;
 pub mod values;
-pub mod config;
 pub mod buffer;
 pub mod encode;
 pub mod decode;
 
 pub use values::*;
-pub use config::StrConfig;
 pub use buffer::Buffer;
 pub use encode::{encode_proto, encode_field, encode_number, encode_varint, encode_map, encode_type, encode_sure_type, 
                  encode_str_raw};
