@@ -1,5 +1,5 @@
 extern crate rt_proto as td_rp;
-use td_rp::{Value, StrConfig, Buffer};
+use td_rp::{Value, Buffer};
 
 use std::io::prelude::*;
 use std::mem;
@@ -17,11 +17,10 @@ fn test_head_field(buffer : &mut Buffer, t : u8) {
 
 #[test]
 fn test_encode_u8() {
-    let mut config = StrConfig::new();
     let mut buffer = Buffer::new();
     let value = Value::U8(1 as u8);
-    td_rp::encode_field(&mut buffer, &mut config, &value).unwrap();
-    td_rp::encode_field(&mut buffer, &mut config, &value).unwrap();
+    td_rp::encode_field(&mut buffer, &value).unwrap();
+    td_rp::encode_field(&mut buffer, &value).unwrap();
 
     // first read field
     test_head_field(&mut buffer, td_rp::TYPE_U8);
@@ -32,7 +31,7 @@ fn test_encode_u8() {
     assert_eq!(data[0], 1);
 
     // second read field
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::U8(val) => assert_eq!(val, 1),
         _ => unreachable!("it will not read"),
@@ -44,12 +43,11 @@ fn test_encode_u8() {
 
 #[test]
 fn test_encode_16() {
-    let mut config = StrConfig::new();
     let mut buffer = Buffer::new();
     
     //-1
-    td_rp::encode_field(&mut buffer, &mut config, &Value::I16(-1 as i16)).unwrap(); 
-    td_rp::encode_field(&mut buffer, &mut config, &Value::U16(0x1234 as u16)).unwrap();
+    td_rp::encode_field(&mut buffer, &Value::I16(-1 as i16)).unwrap(); 
+    td_rp::encode_field(&mut buffer, &Value::U16(0x1234 as u16)).unwrap();
 
     // first read field
     test_head_field(&mut buffer, td_rp::TYPE_VARINT);
@@ -60,7 +58,7 @@ fn test_encode_16() {
     assert_eq!(data[0], 0x01);
 
     // second read field
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::Varint(val) => assert_eq!(val, 0x1234),
         _ => unreachable!("it will not read"),
@@ -72,13 +70,12 @@ fn test_encode_16() {
 
 #[test]
 fn test_encode_u32() {
-    let mut config = StrConfig::new();
     let mut buffer = Buffer::new();
     let data: &mut [u8; 4] = &mut [0, 0, 0, 0];
-    td_rp::encode_field(&mut buffer, &mut config, &Value::U32(0x12345678 as u32)).unwrap();
+    td_rp::encode_field(&mut buffer, &Value::U32(0x12345678 as u32)).unwrap();
 
     // second read field
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::Varint(val) => assert_eq!(val, 0x12345678),
         _ => unreachable!("it will not read"),
@@ -90,14 +87,13 @@ fn test_encode_u32() {
 
 #[test]
 fn test_encode_float() {
-    let mut config = StrConfig::new();
     let mut buffer = Buffer::new();
     let value = Value::Float(12345.123);
     let data: &mut [u8; 4] = &mut [0, 0, 0, 0];
-    td_rp::encode_field(&mut buffer, &mut config, &value).unwrap();
+    td_rp::encode_field(&mut buffer, &value).unwrap();
 
     // second read field
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::Varint(val) => assert_eq!(val, 12345123),
         _ => unreachable!("it will not read"),
@@ -108,14 +104,13 @@ fn test_encode_float() {
 
 #[test]
 fn test_encode_str() {
-    let mut config = StrConfig::new();
     let mut buffer = Buffer::new();
     let name = "I'm a chinese people";
     let value = Value::Str(name.to_string());
     td_rp::encode_type(&mut buffer, &value).unwrap();
     td_rp::encode_str_raw(&mut buffer, &value).unwrap();
     
-    td_rp::encode_field(&mut buffer, &mut config, &value).unwrap();
+    td_rp::encode_field(&mut buffer, &value).unwrap();
 
     // first read field
     test_head_field(&mut buffer, td_rp::TYPE_STR);
@@ -131,7 +126,7 @@ fn test_encode_str() {
     assert_eq!(&*val, name);
 
     // second read field
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::Str(val) => assert_eq!(&*val, name),
         _ => unreachable!("it will not read"),
@@ -140,17 +135,16 @@ fn test_encode_str() {
 
 #[test]
 fn test_encode_map() {
-    let mut config = td_rp::StrConfig::new();
     let mut hash_value = HashMap::<Value, Value>::new();
     hash_value.insert(Value::Str("name".to_string()), Value::Str("I'm a chinese people".to_string()));
     hash_value.insert(Value::Str("sub_name".to_string()), Value::Str("tickdream".to_string()));
     hash_value.insert(Value::Str("index".to_string()), Value::U16(1 as u16));
     {
         let mut buffer = Buffer::new();
-        td_rp::encode_field(&mut buffer, &mut config, &Value::Map(hash_value.clone())).unwrap();
+        td_rp::encode_field(&mut buffer, &Value::Map(hash_value.clone())).unwrap();
 
         // just read field
-        let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+        let read = td_rp::decode_field(&mut buffer).unwrap();
         match read {
             Value::Map(val) => assert_eq!(val, hash_value),
             _ => unreachable!("it will not read"),
@@ -161,10 +155,10 @@ fn test_encode_map() {
     undefined.insert(Value::Str("undefine".to_string()), Value::U16(1 as u16));
     {
         let mut buffer = Buffer::new();
-        td_rp::encode_field(&mut buffer, &mut config, &Value::Map(undefined.clone())).unwrap();
+        td_rp::encode_field(&mut buffer, &Value::Map(undefined.clone())).unwrap();
 
         // just read field
-        let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+        let read = td_rp::decode_field(&mut buffer).unwrap();
         match read {
             Value::Map(val) => assert_eq!(val, undefined),
             _ => unreachable!("it will not read"),
@@ -174,16 +168,15 @@ fn test_encode_map() {
 
 #[test]
 fn test_encode_array_u8() {
-    let mut config = StrConfig::new();
     let mut array : Vec<Value> = vec![];
     for i in 0 .. 10 {
         array.push(Value::U8(i as u8));
     }
 
     let mut buffer = Buffer::new();
-    td_rp::encode_field(&mut buffer, &mut config, &Value::Arr(array.clone())).unwrap();
+    td_rp::encode_field(&mut buffer, &Value::Arr(array.clone())).unwrap();
 
-    let read = td_rp::decode_field(&mut buffer, &config).unwrap();
+    let read = td_rp::decode_field(&mut buffer).unwrap();
     match read {
         Value::Arr(ref val) => {
             assert_eq!(*val, array);
